package core

import (
	"errors"
	"github.com/louisevanderlith/husk"
)

type Vehicle struct {
	VINKey    husk.Key
	FullVIN   string
	Series    SeriesInfo
	Colour    string
	PaintNo   string
	Month     int
	Year      int
	Engine    Engine
	Gearbox   Gearbox
	BodyStyle string
	Doors     int
	Trim      string
	Extra     []string
}

func (m Vehicle) Valid() (bool, error) {
	return husk.ValidateStruct(&m)
}

func GetYears() (map[int]struct{}, error) {
	result := make(map[int]struct{})
	err := ctx.Vehicles.Calculate(&result, Years())

	if err != nil {
		return nil, err
	}

	return result, nil
}

func GetManufacturers(year int) (map[string]struct{}, error) {
	result := make(map[string]struct{})
	err := ctx.Vehicles.Calculate(&result, Manufacturers(year))

	if err != nil {
		return nil, err
	}

	return result, nil
}

func GetModels(year int, manufacturer string) (map[string]struct{}, error) {
	result := make(map[string]struct{})
	err := ctx.Vehicles.Calculate(&result, Models(year, manufacturer))

	if err != nil {
		return nil, err
	}

	return result, nil
}

func GetTrims(year int, manufacturer, model string) (map[string]struct{}, error) {
	result := make(map[string]struct{})
	err := ctx.Vehicles.Calculate(&result, Trim(year, manufacturer, model))

	if err != nil {
		return nil, err
	}

	return result, nil
}

func GetVehicles(page, pagesize int) (husk.Collection, error) {
	return ctx.Vehicles.Find(page, pagesize, husk.Everything())
}

func GetVehicle(key husk.Key) (husk.Recorder, error) {
	return ctx.Vehicles.FindByKey(key)
}

func (obj Vehicle) Create() (husk.Recorder, error) {
	if ctx.Vehicles.Exists(byFullVIN(obj.FullVIN)) {
		return nil, errors.New("vehicle VIN already exists")
	}

	rec := ctx.Vehicles.Create(obj)

	if rec.Error != nil {
		return nil, rec.Error
	}

	ctx.Vehicles.Save()

	return rec.Record, nil
}
